
WITH Compression_Parameters;
WITH Memory_Definition_1750a;

PACKAGE Compression_Instance IS

  SUBTYPE Object_Count IS Memory_Definition_1750a.Byte_Count;
  SUBTYPE Object_Value IS Memory_Definition_1750a.Byte_Value;
  SUBTYPE Object_Index IS Memory_Definition_1750a.Byte_Location;
  SUBTYPE Object_Array IS Memory_Definition_1750a.Byte_Array;

  TYPE Count_Limits IS ARRAY( Compression_Parameters.Length_Parameter )
                    OF Object_Count;


  SUBTYPE Working_Space IS Object_Array( 0 ..  Object_Index( 2 ** 17 - 1 ) );
    -- Maximum address space for "byte" (not "word") values.



  PROCEDURE Initialize_Package
    ( Compress_Options : IN Compression_Parameters.Compression_Options :=
                            Compression_Parameters.Default_Options );

    -- Initializes the processing characteristics of this package.


  FUNCTION Get_Count_Limits RETURN Count_Limits;

    -- Compression token maximum storage values.


  PROCEDURE Compress_Data
    ( Source_List : IN Object_Array;
      Source_Head : IN Object_Index;
      Target_List : IN OUT Object_Array;
      Target_Tail : IN OUT Object_Count );

    -- Perform the compression on the input source data array.
    -- The result will be stored in the Target array, with Length being
    -- set to the last array index used.


  PROCEDURE Uncompress_Data
    ( Source_List : IN Object_Array;
      Source_Head : IN Object_Index;
      Target_List : IN OUT Object_Array;
      Target_Tail : IN OUT Object_Count );

    -- Perform the decompression on the input source data array.
    -- The result will be stored in the Target array, with Length being
    -- set to the last array index used.


  PROCEDURE Verify_Translation
    ( Is_Verified : OUT Boolean;
      Last_Backup : OUT Object_Count;
      Last_Length : OUT Object_Count );

    -- This procedure can be called once during test to verify that the
    -- Marker_Token encryption scheme is correct.  It essentially verifies
    -- that no encryption of any combination of token offset count and token
    -- size will place a Marker_Token in the first field of the special token.


END Compression_Instance;
