
WITH Text_IO;

PACKAGE BODY Compression_Statistics IS

  TYPE Computation_Range IS DIGITS 4; -- Don't need much...

  Before_Decimal : CONSTANT := 4;
  After_Decimal  : CONSTANT := 2;


  PACKAGE Real_IO IS NEW Text_IO.Float_IO( Computation_Range );



  FUNCTION Image( Value : IN Computation_Range ) RETURN String IS
      Size : CONSTANT Natural := Before_Decimal + 1 + After_Decimal;
      Text : String( 1 .. Size );
  BEGIN
      Real_IO.Put( Text, Value, After_Decimal, 0 );
      RETURN Text;
  END Image;



  FUNCTION Ratio_Image
    ( From : IN Computation_Range;
      Over : IN Computation_Range ) RETURN String IS
  BEGIN
      RETURN Image( From / Over );
  EXCEPTION
      WHEN Standard.Constraint_Error | Standard.Numeric_Error =>
          RETURN " " &
                 String'( 2 .. Before_Decimal => '*' ) &
                 "." &
                 String'( 1 .. After_Decimal => '*' );
  END Ratio_Image;



  FUNCTION Percent_Image
    ( Partial_Size : IN Value_Count;
      Out_Of_Total : IN Value_Count ) RETURN String IS
  BEGIN
      RETURN Ratio_Image( From => 100.0 * Computation_Range( Partial_Size ),
                          Over => Computation_Range( Out_Of_Total ) ) & "%";
  END Percent_Image;



  FUNCTION Saved_Image
    ( Went_From_Size : IN Value_Count;
      Down_To_Length : IN Value_Count ) RETURN String IS
  BEGIN
      RETURN Ratio_Image
               ( From => 100.0 *
                         ( Computation_Range( Went_From_Size ) -
                           Computation_Range( Down_To_Length ) ),
                 Over => Computation_Range( Went_From_Size ) ) & "%";
  END Saved_Image;



  FUNCTION Ratio_Image
    ( Went_From_Size : IN Value_Count;
      Down_To_Length : IN Value_Count ) RETURN String IS
  BEGIN
      RETURN Ratio_Image( From => Computation_Range( Went_From_Size ),
                          Over => Computation_Range( Down_To_Length ) );
  END Ratio_Image;



  PROCEDURE Print_Report
    ( Went_From_Size : IN Value_Count;
      Down_To_Length : IN Value_Count;
      Use_Table_Head : IN String := "" ) IS
  BEGIN
      Print( Use_Table_Head & "Compression Ratio:" &
             Ratio_Image( Went_From_Size, Down_To_Length ) & " to 1" );
      Print( Use_Table_Head & "Percentage Saved:     " &
             Saved_Image( Went_From_Size, Down_To_Length ) );
      Print( Use_Table_Head & "Went from" &
             Value_Count'IMAGE( Went_From_Size ) &
             " to" & Value_Count'IMAGE( Down_To_Length ) );
  END Print_Report;



END Compression_Statistics;
