
WITH Compression_Instance;

PACKAGE Compression_Support IS

  Version : CONSTANT String := "1.1";
  Changed : CONSTANT String := "12/15/92";

  Created : CONSTANT String := "10/10/92";
  Company : CONSTANT String := "The Aerospace Corporation";


  -- This package manages the input and output required by the various
  -- compression utility programs, including an extensive amount of
  -- error checking and diagnostics.

  -- It manages the proper initialization of the compression package,
  -- the reading/writing and format of the memory map files,
  -- and the reading/writing and format of the parameter file.


  Unable_To_Initialize : EXCEPTION;


  PROCEDURE Print( Text : IN String );
  PROCEDURE Error( Text : IN String );

  FUNCTION Image( Index : IN Compression_Instance.Object_Count ) RETURN String;



  PROCEDURE Initialize_Compression
    ( Label                : IN String;
      Read_Parameters_Only : IN Boolean := False;
      Will_Save_Parameters : IN Boolean := False );


  PROCEDURE Start_Timer;
  PROCEDURE Stop_Timer;
  -- The elapsed time between calls to Start_Timer and Stop_Timer
  -- will be included in the next call to Print_Report.


  PROCEDURE Print_Report
    ( Label       : IN String;
      Source_List : IN Compression_Instance.Object_Array;
      Source_Head : IN Compression_Instance.Object_Index;
      Source_Tail : IN Compression_Instance.Object_Index;
      Target_List : IN Compression_Instance.Object_Array;
      Target_Head : IN Compression_Instance.Object_Index;
      Target_Tail : IN Compression_Instance.Object_Index );

  PROCEDURE Save_Parameters
    ( Source_List : IN Compression_Instance.Object_Array;
      Source_Head : IN Compression_Instance.Object_Index;
      Source_Tail : IN Compression_Instance.Object_Index );


  PROCEDURE Load_Memory
    ( List : IN OUT Compression_Instance.Object_Array;
      Head : OUT Compression_Instance.Object_Index;
      Last : OUT Compression_Instance.Object_Index );

  PROCEDURE Save_Memory
    ( List : IN Compression_Instance.Object_Array;
      Head : IN Compression_Instance.Object_Index;
      Last : IN Compression_Instance.Object_Index );

END Compression_Support;
