
WITH Compression_Support;
WITH Compression_Instance;

PROCEDURE Compression_Verify IS

  -- This procedure should always be used once for each different set of
  -- compression parameters to verify that they are internally consistent.
  -- This procedure will read in the compression parameters, and then
  -- iterate through all combinations of encoded marker coordinates
  -- ( length, offset ) to verify that the encrypted coordinates will
  -- decrypt to the same values.  If a problem is discovered, the
  -- first pair of coordinates that did not encrypt/decrypt successfully
  -- will be printed.


  PROCEDURE Print( Text : String ) RENAMES Compression_Support.Print;

  FUNCTION Image( Item : Compression_Instance.Object_Count )
       RETURN String RENAMES Compression_Support.Image;


  Is_Verified : Boolean := False;
  Last_Backup : Compression_Instance.Object_Count := 0;
  Last_Length : Compression_Instance.Object_Count := 0;

BEGIN

  Compression_Support.Initialize_Compression
    ( "Compression Verify Utility",
      Read_Parameters_Only => True );

  Compression_Instance.Verify_Translation
    ( Is_Verified => Is_Verified,
      Last_Backup => Last_Backup,
      Last_Length => Last_Length );

  IF Is_Verified THEN
      Print( "Verification successful." );
  ELSE
      Print( "Verification FAILED." );
      Print( "" );
      Print( "  First Problem Backup => " & Image( Last_Backup ) );
      Print( "  First Problem Length => " & Image( Last_Length ) );
      Print( "" );
  END IF;

END Compression_Verify;
