
PACKAGE Memory_Definition_1750a IS

  Storage_Unit : CONSTANT := 16;
  Maximum_Page : CONSTANT := 16;

  Bytes_Per_Word : CONSTANT := 2;
  Bits_Per_Byte  : CONSTANT := Storage_Unit / Bytes_Per_Word;

  Minimum_Integer : CONSTANT := - 2 ** ( Storage_Unit - 1 );
  Maximum_Integer : CONSTANT := 2 ** ( Storage_Unit - 1 ) - 1;

  Minimum_Address : CONSTANT := 0;
  Maximum_Address : CONSTANT := 2 ** Storage_Unit - 1;

  Maximum_Physical_Words : CONSTANT := ( Maximum_Address + 1 ) * Maximum_Page;
  Maximum_Physical_Bytes : CONSTANT := Maximum_Physical_Words * Bytes_Per_Word;


  TYPE Page_Index IS RANGE 0 .. Maximum_Page - 1;

  TYPE Byte_Value IS RANGE 0 .. 2 ** Bits_Per_Byte - 1;
  --FOR Byte_Value'SIZE USE Bits_Per_Byte;

  TYPE Byte_Index IS RANGE 0 .. Bytes_Per_Word - 1;
  TYPE Word_Value IS ARRAY( Byte_Index ) OF Byte_Value;
  PRAGMA Pack( Word_Value );


  TYPE Memory_Address IS RANGE Minimum_Address .. Maximum_Physical_Words - 1;
  TYPE Stored_Address IS RANGE Minimum_Address .. Maximum_Address;
  TYPE Memory_Integer IS RANGE Minimum_Integer .. Maximum_Integer;

  --FOR Memory_Integer'SIZE USE Storage_Unit;
  --FOR Stored_Address'SIZE USE Storage_Unit;


  TYPE Memory_Array IS ARRAY( Memory_Address RANGE <> ) OF Memory_Integer;
  TYPE Memory_Words IS ARRAY( Memory_Address RANGE <> ) OF Word_Value;

  TYPE Word_Count IS RANGE 0 .. Maximum_Physical_Words;
  TYPE Byte_Count IS RANGE 0 .. Maximum_Physical_Bytes;

  SUBTYPE Word_Location IS Word_Count RANGE 0 .. Maximum_Physical_Words - 1;
  SUBTYPE Byte_Location IS Byte_Count RANGE 0 .. Maximum_Physical_Bytes - 1;

  TYPE Word_Array IS ARRAY( Word_Location RANGE <> ) OF Word_Value;
  TYPE Byte_Array IS ARRAY( Byte_Location RANGE <> ) OF Byte_Value;


  FUNCTION To_Integer( Value : IN Word_Value ) RETURN Memory_Integer;
  FUNCTION To_Address( Value : IN Word_Value ) RETURN Stored_Address;

  FUNCTION Convert( Value : IN Memory_Integer ) RETURN Word_Value;
  FUNCTION Convert( Value : IN Stored_Address ) RETURN Word_Value;

END Memory_Definition_1750a;
