
PACKAGE BODY Memory_Supporting_1750a IS

  TYPE Digit_Range IS RANGE 0 .. 15;

  Hex_Digit : CONSTANT Array( Digit_Range ) OF Character := "0123456789ABCDEF";



  FUNCTION Fill( Text : IN String; Size : IN Natural ) RETURN String IS
      Head : Natural := Text'FIRST;
  BEGIN
      WHILE Head IN Text'RANGE AND THEN Text( Head ) = ' ' LOOP
          Head := Head + 1;
      END LOOP;
      RETURN String'( Text'LAST + 2 .. Size + Head => ' ' ) &
             Text( Head .. Text'LAST );
  EXCEPTION
      WHEN Standard.Constraint_Error =>
          RETURN Text( Head .. Text'LAST );
  END Fill;



  FUNCTION Hex_Image
    ( Item : IN Compute_Range;
      Size : IN Natural := 4;
      Pads : IN Character := ' ' ) RETURN String IS

      Based : CONSTANT := 16;
      Value : Compute_Range := Item;
      Image : String( 1 .. Size ) := ( OTHERS => Pads );
      Found : Natural := Image'LAST;

  BEGIN
      Image( Image'LAST ) := '0';
      WHILE Value NOT IN 0 .. 0 LOOP
          Image( Found ) := Hex_Digit( Digit_Range( Value MOD Based ) );
          Value := Value / Based;
          Found := Found - 1;
      END LOOP;
      RETURN Image;
  EXCEPTION
      WHEN Standard.Constraint_Error =>
          RETURN String'( 1 .. Size => '*' );
  END Hex_Image;



  FUNCTION Hex_Image( Value : IN Memory_Definition_1750a.Byte_Value )
      RETURN String IS
  BEGIN
      RETURN Hex_Image( Item => Compute_Range( Value ),
                        Size => 2,
                        Pads => '0' );
  END Hex_Image;



  FUNCTION Hex_Image( Value : IN Memory_Definition_1750a.Memory_Address )
      RETURN String IS
  BEGIN
      RETURN Hex_Image( Item => Compute_Range( Value ),
                        Size => 5,
                        Pads => '0' );
  END Hex_Image;



  FUNCTION Hex_Image( Value : IN Memory_Definition_1750a.Byte_Count )
      RETURN String IS
  BEGIN
      RETURN Hex_Image( Item => Compute_Range( Value ),
                        Size => 6,
                        Pads => '0' );
  END Hex_Image;



  FUNCTION Hex_Image( Value : IN Memory_Definition_1750a.Memory_Integer )
      RETURN String IS
  BEGIN
      RETURN Hex_Image( Item => Compute_Range( Value ),
                        Size => 6,
                        Pads => ' ' );
  END Hex_Image;



  FUNCTION Image( Value : IN Memory_Definition_1750a.Memory_Address )
      RETURN String IS
  BEGIN
      RETURN Fill( Memory_Definition_1750a.Memory_Address'IMAGE( Value ), 5 );
  END Image;



  FUNCTION Image( Value : IN Memory_Definition_1750a.Memory_Integer )
      RETURN String IS
  BEGIN
      RETURN Fill( Memory_Definition_1750a.Memory_Integer'IMAGE( Value ), 6 );
  END Image;



  FUNCTION Image( Value : IN Memory_Definition_1750a.Byte_Value )
      RETURN String IS
  BEGIN
      RETURN Fill( Memory_Definition_1750a.Byte_Value'IMAGE( Value ), 3 );
  END Image;



  FUNCTION Image( Value : IN Memory_Definition_1750a.Word_Value )
      RETURN String IS
  BEGIN
      RETURN "(" & Image( Value( 0 ) ) & "," & Image( Value( 1 ) ) & ")";
  END Image;



  FUNCTION Image( Value : IN Memory_Definition_1750a.Byte_Count )
      RETURN String IS
  BEGIN
      RETURN Fill( Memory_Definition_1750a.Byte_Count'IMAGE( Value ), 6 );
  END Image;



  FUNCTION Image( Value : IN Memory_Definition_1750a.Word_Count )
      RETURN String IS
  BEGIN
      RETURN Fill( Memory_Definition_1750a.Word_Count'IMAGE( Value ), 6 );
  END Image;



END Memory_Supporting_1750a;
